<?php
/**
 * Register custom customizer panels, sections and settings.
 *
 * @package    Silver
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * We register our custom customizer by using the hook.
 *
 * @since  1.0.0
 */
function silver_customizer_register() {

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// ======= Start Customizer Panels/Sections/Settings ======= //

	// Typography Panel and Sections
	$typo_panel = 'typography';

	$panels[] = array(
		'id'          => $typo_panel,
		'title'       => esc_html__( 'Typography', 'silver' ),
		'description' => esc_html__( 'This panel is used for managing typography of your site.', 'silver' ),
		'priority'    => 50
	);

		// Global typography
		$section = PREFIX . 'global-typography';
		$font_choices = customizer_library_get_font_choices();

		$sections[] = array(
			'id'       => $section,
			'title'    => esc_html__( 'Global', 'silver' ),
			'priority' => 5,
			'panel'    => $typo_panel
		);
		$options[PREFIX . 'text-font'] = array(
			'id'          => PREFIX . 'text-font',
			'label'       => esc_html__( 'Body font', 'silver' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Roboto',
		);
		$options[PREFIX . 'heading-font'] = array(
			'id'          => PREFIX . 'heading-font',
			'label'       => esc_html__( 'Heading font', 'silver' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Prata',
		);
		$options[PREFIX . 'elements-font'] = array(
			'id'          => PREFIX . 'elements-font',
			'label'       => esc_html__( 'Element font', 'silver' ),
			'description' => esc_html__( 'Font for button, pagination, etc.', 'silver' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Montserrat',
		);

	/**
	 * Colors
	 */

	// Accent color
	$options[PREFIX . 'accent-colors'] = array(
		'id'          => PREFIX . 'accent-colors',
		'label'       => esc_html__( 'Accent Colors', 'silver' ),
		'section'     => 'colors',
		'type'        => 'color',
		'default'     => '#ff9999'
	);

	// Theme Panels and Sections
	$theme_options = 'theme_options';

	$panels[] = array(
		'id'          => $theme_options,
		'title'       => esc_html__( 'Theme Options', 'silver' ),
		'description' => esc_html__( 'This panel is used for managing general section of your site.', 'silver' ),
		'priority'    => 190
	);

		// Featured Posts
		$section = PREFIX . 'featured-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Featured Posts', 'silver' ),
			'description' => esc_html__( 'Featured posts is a posts slider on home page.', 'silver' ),
			'priority'    => 5,
			'panel'       => $theme_options
		);
			$options[PREFIX . 'featured-enable'] = array(
				'id'          => PREFIX . 'featured-enable',
				'label'       => esc_html__( 'Show featured posts', 'silver' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'featured-tag'] = array(
				'id'          => PREFIX . 'featured-tag',
				'label'       => esc_html__( 'Select a tag', 'silver' ),
				'section'     => $section,
				'type'        => 'select2',
				'choices'     => silver_tags_list()
			);
			$options[PREFIX . 'featured-num'] = array(
				'id'          => PREFIX . 'featured-num',
				'label'       => esc_html__( 'Number of posts', 'silver' ),
				'section'     => $section,
				'type'        => 'text',
				'default'     => 6
			);
			$options[PREFIX . 'featured-orderby'] = array(
				'id'          => PREFIX . 'featured-orderby',
				'label'       => esc_html__( 'Order by', 'silver' ),
				'section'     => $section,
				'type'        => 'select',
				'default'     => 'date',
				'choices'     => array(
					'date'  => esc_html__( 'Date', 'silver' ),
					'rand'  => esc_html__( 'Random', 'silver' )
				)
			);

		// Promo Box
		$section = PREFIX . 'promobox-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Promo Box', 'silver' ),
			'priority'    => 10,
			'panel'       => $theme_options,
		);
		$options[PREFIX . 'promobox-1'] = array(
			'id'          => PREFIX . 'promobox-1',
			'label'       => esc_html__( 'Promo Box 1', 'silver' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'promobox-1-img'] = array(
				'id'      => PREFIX . 'promobox-1-img',
				'label'   => esc_html__( 'Image', 'silver' ),
				'section' => $section,
				'type'    => 'media',
				'default' => ''
			);
			$options[PREFIX . 'promobox-1-url'] = array(
				'id'           => PREFIX . 'promobox-1-url',
				'label'        => esc_html__( 'URL', 'silver' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);
			$options[PREFIX . 'promobox-1-text'] = array(
				'id'           => PREFIX . 'promobox-1-text',
				'label'        => esc_html__( 'Text', 'silver' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
		$options[PREFIX . 'promobox-2'] = array(
			'id'          => PREFIX . 'promobox-2',
			'label'       => esc_html__( 'Promo Box 2', 'silver' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'promobox-2-img'] = array(
				'id'      => PREFIX . 'promobox-2-img',
				'label'   => esc_html__( 'Image', 'silver' ),
				'section' => $section,
				'type'    => 'media',
				'default' => ''
			);
			$options[PREFIX . 'promobox-2-url'] = array(
				'id'           => PREFIX . 'promobox-2-url',
				'label'        => esc_html__( 'URL', 'silver' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);
			$options[PREFIX . 'promobox-2-text'] = array(
				'id'           => PREFIX . 'promobox-2-text',
				'label'        => esc_html__( 'Text', 'silver' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
		$options[PREFIX . 'promobox-3'] = array(
			'id'          => PREFIX . 'promobox-3',
			'label'       => esc_html__( 'Promo Box 3', 'silver' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'promobox-3-img'] = array(
				'id'      => PREFIX . 'promobox-3-img',
				'label'   => esc_html__( 'Image', 'silver' ),
				'section' => $section,
				'type'    => 'media',
				'default' => ''
			);
			$options[PREFIX . 'promobox-3-url'] = array(
				'id'           => PREFIX . 'promobox-3-url',
				'label'        => esc_html__( 'URL', 'silver' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);
			$options[PREFIX . 'promobox-3-text'] = array(
				'id'           => PREFIX . 'promobox-3-text',
				'label'        => esc_html__( 'Text', 'silver' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
		$options[PREFIX . 'promobox-4'] = array(
			'id'          => PREFIX . 'promobox-4',
			'label'       => esc_html__( 'Promo Box 4', 'silver' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'promobox-4-img'] = array(
				'id'      => PREFIX . 'promobox-4-img',
				'label'   => esc_html__( 'Image', 'silver' ),
				'section' => $section,
				'type'    => 'media',
				'default' => ''
			);
			$options[PREFIX . 'promobox-4-url'] = array(
				'id'           => PREFIX . 'promobox-4-url',
				'label'        => esc_html__( 'URL', 'silver' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);
			$options[PREFIX . 'promobox-4-text'] = array(
				'id'           => PREFIX . 'promobox-4-text',
				'label'        => esc_html__( 'Text', 'silver' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);

		// Posts
		$section = PREFIX . 'posts-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Posts', 'silver' ),
			'priority'    => 10,
			'panel'       => $theme_options
		);
		$options[PREFIX . 'post-featured'] = array(
			'id'          => PREFIX . 'post-featured',
			'label'       => esc_html__( 'Show featured image', 'silver' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'post-cat'] = array(
			'id'          => PREFIX . 'post-cat',
			'label'       => esc_html__( 'Show post categories', 'silver' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'post-tag'] = array(
			'id'          => PREFIX . 'post-tag',
			'label'       => esc_html__( 'Show post tags', 'silver' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'post-share'] = array(
			'id'          => PREFIX . 'post-share',
			'label'       => esc_html__( 'Show post share', 'silver' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[PREFIX . 'post-author-box'] = array(
			'id'          => PREFIX . 'post-author-box',
			'label'       => esc_html__( 'Show post author box', 'silver' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Page
		$section = PREFIX . 'page-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Page', 'silver' ),
			'priority'    => 10,
			'panel'       => $theme_options
		);
		$options[PREFIX . 'page-title'] = array(
			'id'          => PREFIX . 'page-title',
			'label'       => esc_html__( 'Show page title', 'silver' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Instagram
		$section = PREFIX . 'instagram-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Instagram', 'silver' ),
			'priority'    => 15,
			'panel'       => $theme_options
		);
		$options[PREFIX . 'instagram-token'] = array(
			'id'      => PREFIX . 'instagram-token',
			'label'   => esc_html__( 'API Key', 'silver' ),
			'section' => $section,
			'type'    => 'text',
			'default' => ''
		);
		$options[PREFIX . 'instagram-username'] = array(
			'id'      => PREFIX . 'instagram-username',
			'label'   => esc_html__( 'Username', 'silver' ),
			'section' => $section,
			'type'    => 'text',
			'default' => ''
		);
		$options[PREFIX . 'instagram-userid'] = array(
			'id'      => PREFIX . 'instagram-userid',
			'label'   => esc_html__( 'User ID', 'silver' ),
			'section' => $section,
			'type'    => 'text',
			'default' => ''
		);
		$options[PREFIX . 'instagram-limit'] = array(
			'id'      => PREFIX . 'instagram-limit',
			'label'   => esc_html__( 'Number of photos to show', 'silver' ),
			'section' => $section,
			'type'    => 'number',
			'default' => 9
		);

		// Extra Options
		$section = PREFIX . 'extra-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Misc Options', 'silver' ),
			'priority'    => 99,
			'panel'       => $theme_options,
		);

			$options[PREFIX . 'custom-rss'] = array(
				'id'           => PREFIX . 'custom-rss',
				'label'        => esc_html__( 'RSS URL', 'silver' ),
				'description'  => esc_html__( 'Custom RSS URL such as Feedburner.', 'silver' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);

			$options[PREFIX . 'page-comment'] = array(
				'id'           => PREFIX . 'page-comment',
				'label'        => esc_html__( 'Page Comment', 'silver' ),
				'description'  => esc_html__( 'Allow people to post comments on page.', 'silver' ),
				'section'      => $section,
				'type'         => 'switch',
				'default'      => 1
			);

			$options[PREFIX . 'footer-text'] = array(
				'id'           => PREFIX . 'footer-text',
				'label'        => esc_html__( 'Footer Text', 'silver' ),
				'description'  => esc_html__( 'Customize the footer text.', 'silver' ),
				'section'      => $section,
				'type'         => 'textarea',
				'default'      => 'Designed by <a href="https://www.theme-junkie.com/">Theme Junkie</a>'
			);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

}
add_action( 'init', 'silver_customizer_register' );
